ZigCompiler

Struct ZigCompiler 

pub struct ZigCompiler { /* private fields */ }
Wrapper for invoking the Zig compiler

Implementations

Source

impl ZigCompiler

pub fn new() -> Self

Create a new Zig compiler wrapper

pub fn check_version(&self) -> Result<String>

Check Zig compiler version

pub fn compile_with_target( &self, source: &Path, output_lib: &Path, target: &str, ) -> Result<()>

Compile Zig source to static library with target support

Arguments
  • source - Path to .zig source file
  • output_lib - Path for output static library (.a)
  • target - Target triple (e.g., “x86_64-linux-gnu”, “native”, “wasm32-freestanding”)
pub fn compile_with_target_and_src( &self, source: &Path, output_lib: &Path, target: &str, src_dir: &Path, ) -> Result<()>

Compile with target and search for C sources in the provided src directory

Arguments
  • source - Path to .zig source file (usually in OUT_DIR)
  • output_lib - Path for output static library (.a)
  • target - Target triple (e.g., “x86_64-linux-gnu”, “native”, “wasm32-freestanding”)
  • src_dir - Original source directory to search for C files
pub fn compile(&self, source: &Path, output_lib: &Path) -> Result<()>

Compile with native target (convenience method)

pub fn compile_tests( &self, source: &Path, output_exe: &Path, target: &str, ) -> Result<()>

Compile Zig tests to an executable

Arguments
  • source - Path to .zig source file containing tests
  • output_exe - Path for output test executable
  • target - Target triple (e.g., “x86_64-linux-gnu”, “native”)
pub fn run_test_executable(&self, test_exe: &Path) -> Result<String>

Run compiled Zig test executable

Arguments
  • test_exe - Path to compiled test executable