pub struct ZigCompiler { /* private fields */ }Expand description
Wrapper for invoking the Zig compiler
Implementations
Sourceimpl ZigCompiler
impl ZigCompiler
Sourcepub fn check_version(&self) -> Result<String>
pub fn check_version(&self) -> Result<String>
Check Zig compiler version
Sourcepub fn compile_with_target(
&self,
source: &Path,
output_lib: &Path,
target: &str,
) -> Result<()>
pub fn compile_with_target( &self, source: &Path, output_lib: &Path, target: &str, ) -> Result<()>
Compile Zig source to static library with target support
Arguments
source- Path to .zig source fileoutput_lib- Path for output static library (.a)target- Target triple (e.g., “x86_64-linux-gnu”, “native”, “wasm32-freestanding”)
Sourcepub fn compile_with_target_and_src(
&self,
source: &Path,
output_lib: &Path,
target: &str,
src_dir: &Path,
) -> Result<()>
pub fn compile_with_target_and_src( &self, source: &Path, output_lib: &Path, target: &str, src_dir: &Path, ) -> Result<()>
Compile with target and search for C sources in the provided src directory
Arguments
source- Path to .zig source file (usually in OUT_DIR)output_lib- Path for output static library (.a)target- Target triple (e.g., “x86_64-linux-gnu”, “native”, “wasm32-freestanding”)src_dir- Original source directory to search for C files
Sourcepub fn compile(&self, source: &Path, output_lib: &Path) -> Result<()>
pub fn compile(&self, source: &Path, output_lib: &Path) -> Result<()>
Compile with native target (convenience method)